#
# spec file for package subfinder
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           subfinder
Version:        2.7.0
Release:        3.1
Summary:        Fast passive subdomain enumeration tool
License:        MIT
URL:            https://github.com/projectdiscovery/subfinder
Source0:        https://github.com/projectdiscovery/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zstd
Source2:        fix_cve_2024_0406.patch
Source3:        fix_cve_2025_22872.patch
Patch1:         disable-version-check.patch
BuildRequires:  binutils
BuildRequires:  help2man
BuildRequires:  udev
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.16

%description
subfinder is a subdomain discovery tool that returns valid subdomains for websites, using passive online sources.
It has a simple, modular architecture and is optimized for speed.
subfinder is built for doing one thing only - passive subdomain enumeration, and it does that very well.
We have made it to comply with all the used passive source licenses and usage restrictions.
The passive model guarantees speed and stealthiness that can be leveraged by both penetration testers and bug bounty hunters alike.

%prep
%autosetup -p1 -a1
patch -d vendor/github.com/mholt/archiver/v3 < %{S:2}
patch -d vendor/golang.org/x/net/ -p1 < %{S:3}

%build
cd v2
ln -s ../vendor
make GOFLAGS="-mod=vendor -buildmode=pie -v"
ls -l
strip subfinder
help2man -s8 -N ./subfinder --version-string=%{version} > subfinder.8

%install
cd v2
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}
install -m 644 -D -v %{name}.8 %{buildroot}%{_datadir}/man/man8/%{name}.8

%check
cd v2
./subfinder -h

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/man/man8/%{name}.8%{?ext_man}

%changelog
* Fri Apr 25 2025 Dominik Heidler <dheidler@suse.de>
- Add fix_cve_2025_22872.patch to patch CVE-2025-22872 / bsc#1241750
* Tue Apr 15 2025 Dominik Heidler <dheidler@suse.de>
- Add fix_cve_2024_0406.patch to patch github.com/mholt/archive dependency
  for bsc#1241187 / CVE-2024-0406 / GHSA-rhh4-rh7c-7r5v
* Mon Mar 17 2025 Dominik Heidler <dheidler@suse.de>
- Version 2.7.0
  * Added ThreatCrowd source by @hyni03 in #1508
  * Added DigitalYama source by @nukunga in #1517
  * Fixed issue where input with protocols (e.g., https://example.com ) was skipped. Now, the protocol part is removed, allowing example.com to be used by @dogancanbakir in #1516
  * Fixed VirusTotal limit error where the limit couldn't be larger than 40 by @dogancanbakir in #1548
  * Fixed query syntax for Netlas source by @thurrsense in #1529
  * Removed PassiveTotal as it no longer exists by @dogancanbakir in #1515
  * Changed DNSRepo API endpoint to the latest version by @dogancanbakir in #1540
  * Skipped non-200 HTTP responses for Anubis by @dogancanbakir in #1541
* Sun Feb  2 2025 Dominik Heidler <dheidler@suse.de>
- Still show current version
  * Update disable-version-check.patch
* Sat Feb  1 2025 Dominik Heidler <dheidler@suse.de>
- Disable version check
  * Add disable-version-check.patch
* Sat Feb  1 2025 Dominik Heidler <dheidler@suse.de>
- Version 2.6.8
  * Added hudsonrock source by @dogancanbakir in #1481
  * Fixed negative statistics for sitedossier source by @dogancanbakir in #1432
  * Fixed GitHub source' performance issue by @dogancanbakir in #1421
  * Fixed the issue with source initialization to prevent the program from exiting when encountering invalid sources during initialization by @dogancanbakir in #1468
  * Removed the columbus source due to consistently encountering 502 errors by @dogancanbakir in #1430
  * Make failing sources non-default and exclude from the tests by @dogancanbakir in #1475
  * Removed subdomaincenter as its output quality was unsatisfactory by @dogancanbakir in #1500
  * Updated dnsdumpster source to use its new API by @dogancanbakir in #1484
  * Improved the usability of the Subfinder SDK by enabling the return of the source map by @mielverkerken in #1466
* Fri Dec 27 2024 Dominik Heidler <dheidler@suse.de>
- Initial checkin
